summaryrefslogtreecommitdiffstats
path: root/libkdepim/kpimurlrequesterdlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/kpimurlrequesterdlg.h')
-rw-r--r--libkdepim/kpimurlrequesterdlg.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/libkdepim/kpimurlrequesterdlg.h b/libkdepim/kpimurlrequesterdlg.h
index 2d606aa8..ef4cc987 100644
--- a/libkdepim/kpimurlrequesterdlg.h
+++ b/libkdepim/kpimurlrequesterdlg.h
@@ -35,12 +35,12 @@ class KDE_EXPORT KPimURLRequesterDlg
*
* @param url This specifies the initial path of the input line.
* @param text The text to be shown on the label.
* @param parent The widget the dialog will be centered on initially.
*/
- static KURL getURL( const TQString &url = TQString::null,
- const TQString &text = TQString::null,
- TQWidget *parent = 0,
- const TQString &caption = TQString::null );
+ static KURL getURL( const TQString &url = TQString(),
+ const TQString &text = TQString(),
+ TQWidget *tqparent = 0,
+ const TQString &caption = TQString() );
};
#endif // KPIMURLREQUESTDLG_H_INCLUDED
@@ -35,12 +35,12 @@ class KDE_EXPORT KPimURLRequesterDlg
* @param url This specifies the initial path of the input line.
* @param text The text to be shown on the label.
- * @param parent The widget the dialog will be centered on initially.
+ * @param tqparent The widget the dialog will be centered on initially.
*/